
# `v2` API

## Constant

::: src.inspeqtor.v2.constant

## Control

::: src.inspeqtor.v2.control

## Data

::: src.inspeqtor.v2.data

## Optimize

::: src.inspeqtor.v2.optimize

## Predefined

::: src.inspeqtor.v2.predefined

## Utilities

::: src.inspeqtor.v2.utils
